.. _leasequery_store:

Leasequery_store
================

Configuration sections that define Leasequery stores. Each leasequery section must configure exactly one
store. Stores perform the storing of lease data at the end of a DHCPv6 request. They also handle the queries
from Leasequery clients to search in that stored data.

.. toctree::

    lq-sqlite
